[Pcsclite-cvs-commit] r3351 - /trunk/Drivers/ccid/src/commands.c

rousseau at users.alioth.debian.org rousseau at users.alioth.debian.org
Thu Mar 19 14:12:20 UTC 2009


Author: rousseau
Date: Thu Mar 19 14:12:19 2009
New Revision: 3351

URL: http://svn.debian.org/wsvn/pcsclite/?sc=1&rev=3351
Log:
SecurePINModify(): do not reject the command if bNumberMessage = 0xFF
(default value)

Thanks to Martin Paljak for the patch

Modified:
    trunk/Drivers/ccid/src/commands.c

Modified: trunk/Drivers/ccid/src/commands.c
URL: http://svn.debian.org/wsvn/pcsclite/trunk/Drivers/ccid/src/commands.c?rev=3351&op=diff
==============================================================================
--- trunk/Drivers/ccid/src/commands.c (original)
+++ trunk/Drivers/ccid/src/commands.c Thu Mar 19 14:12:19 2009
@@ -475,8 +475,9 @@
 		return IFD_NOT_SUPPORTED;
 	}
 
-	/* Make sure in the beginning if bNumberMessage is valid or not */
-	if (TxBuffer[11] > 3)
+	/* Make sure in the beginning if bNumberMessage is valid or not.
+	 * 0xFF is the default value. */
+	if ((TxBuffer[11] > 3) && (TxBuffer[11] != 0xFF))
 	{
 		DEBUG_INFO2("Wrong bNumberMessage: %d", TxBuffer[11]);
 		return IFD_NOT_SUPPORTED;




More information about the Pcsclite-cvs-commit mailing list